import { authInstance } from "@shared";

import { makeAutoObservable, runInAction } from "mobx";

type Snapshot = {
  ID: string;
  Name: string;
  ParentID: string;
  CreationTime: string;
};

class SnapshotStore {
  snapshots: Snapshot[] = [];
  snapshot: Snapshot | null = null;

  constructor() {
    makeAutoObservable(this);
  }

  getSnapshots = async () => {
    const response = await authInstance.get(`/snapshots`);

    runInAction(() => {
      this.snapshots = response.data;
    });
  };

  deleteSnapshot = async (id: string) => {
    await authInstance.delete(`/snapshots/${id}`);

    runInAction(() => {
      this.snapshots = this.snapshots.filter((snapshot) => snapshot.ID !== id);
    });
  };

  getSnapshot = async (id: string) => {
    const response = await authInstance.get(`/snapshots/${id}`);

    runInAction(() => {
      this.snapshot = response.data;
    });
  };

  restoreSnapshot = async (id: string) => {
    await authInstance.post(`/snapshots/${id}/restore`);
  };

  createSnapshot = async (name: string) => {
    await authInstance.post(`/snapshots`, { name });
  };
}

export const snapshotStore = new SnapshotStore();
