import { authInstance } from "@shared";
import { makeAutoObservable, runInAction } from "mobx";

export type User = {
  id: number;
  email: string;
  is_admin: boolean;
  name: string;
  password?: string;
};

class UserStore {
  users: {
    data: User[];
    loaded: boolean;
  } = {
    data: [],
    loaded: false,
  };
  user: Record<string, User> = {};

  constructor() {
    makeAutoObservable(this);
  }

  getUsers = async () => {
    const response = await authInstance.get("/user");

    runInAction(() => {
      this.users.data = response.data;
      this.users.loaded = true;
    });
  };

  getUser = async (id: number) => {
    if (this.user[id]) return this.user[id];
    const response = await authInstance.get(`/user/${id}`);

    runInAction(() => {
      this.user[id] = response.data as User;
    });

    return response.data;
  };

  deleteUser = async (id: number) => {
    await authInstance.delete(`/user/${id}`);

    runInAction(() => {
      this.users.data = this.users.data.filter((user) => user.id !== id);
      delete this.user[id];
    });
  };

  createUserData: Partial<User> = {
    name: "",
    email: "",
    password: "",
    is_admin: false,
  };

  setCreateUserData = (
    name: string,
    email: string,
    password: string,
    is_admin: boolean
  ) => {
    this.createUserData = { name, email, password, is_admin };
  };

  createUser = async () => {
    let id = 1;
    if (this.users.data.length > 0) {
      id = this.users.data[this.users.data.length - 1].id + 1;
    }
    const response = await authInstance.post("/user", this.createUserData);

    runInAction(() => {
      this.users.data.push({
        id: id,
        ...response.data,
      });
    });
  };

  editUserData: Partial<User> = {
    name: "",
    email: "",
    password: "",
    is_admin: false,
  };

  setEditUserData = (
    name: string,
    email: string,
    password: string,
    is_admin: boolean
  ) => {
    this.editUserData = { name, email, password, is_admin };
  };

  editUser = async (id: number) => {
    const response = await authInstance.patch(`/user/${id}`, this.editUserData);

    runInAction(() => {
      this.users.data = this.users.data.map((user) =>
        user.id === id ? { ...user, ...response.data } : user
      );
      this.user[id] = { ...this.user[id], ...response.data };
    });
  };
}

export const userStore = new UserStore();
